function compute(handles)

A = handles.A;

if isempty(A)
	str = sprintf('Please select or create a matrix!');
	uiwait(warndlg(str,'Warning','modal'));
	set(handles.text19,'string','')
	set(handles.text19,'horizontalalignment','left','fontweight','normal');
	return
else
	n = size(A,1);
	m = str2double(get(handles.nnodes,'string'));
	if (isnan(m)) || (m<=0) || (m > n)
		str_nnodes = sprintf('Please specify a number of nodes between 1 and %d!',n);
		uiwait(warndlg(str_nnodes,'Warning','modal'));
		set(handles.text19,'string','')
		set(handles.text19,'horizontalalignment','left','fontweight','normal');
		return
	end
	
	
	opts = struct('empty','empty');
	
	fun = get(handles.popup_fun,'Value');
	index = get(handles.popup_index,'Value');
	way = get(handles.popup_way,'Value');
	opts.gausstolq = str2double(get(handles.gausstolq,'string'));
	opts.sgcmaxn = str2double(get(handles.sgcmaxn,'string'));
	opts.sgctoll = str2double(get(handles.sgctoll,'string'));
	opts.k = str2double(get(handles.k,'string'));
	opts.show = 3 - get(handles.popup_show,'Value');
	
	switch opts.show
		case 0, str_show = sprintf('no');
		case 1, str_show = sprintf('slow');
		case 2, str_show = sprintf('fast');
	end
	
	%opts
	%pause
	
	switch fun
		case 1      %exponential
			set(handles.editalpha,'Enable', 'off','string','0');
			opts.sgcshift = 2 - get(handles.popup_shift,'Value');
			switch index
				case 1 % subgraph centrality
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					switch way
						case 1
							tic
							[vip, vipvalue, info, ~, ~, S, ~] = sgcenhyb(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcenhyb(A,''exp'',%d,opts)',m);
						case 2
							tic
							[vip, vipvalue, info, S, ~, ~, ~] = sgcenlr(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcenlr(A,''exp'',%d,opts)',m);
						case 3
							tic
							[vip, vipvalue, info, ~, ~] = sgcengauss(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcengauss(A,''exp'',%d,opts)',m);
					end
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				case 2      %communicability
					comm_nod = str2double(get(handles.comm_node,'string'));
					if isnan(comm_nod)
						str = sprintf('Please specify a node!');
						uiwait(warndlg(str,'Warning','modal'));
						set(handles.text19,'string','')
						set(handles.text19,'horizontalalignment','left','fontweight','normal');
						return
					elseif ~sum(A(:,comm_nod))
						str = sprintf('Node %d is not connected',comm_nod);
						uiwait(warndlg(str,'Warning','modal'));
						set(handles.text19,'string','')
						set(handles.text19,'horizontalalignment','left','fontweight','normal');
						return
						
					else
						%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
						switch way
							case 1
								tic
								[vip, vipvalue, info, ~, ~, S, ~] = commhyb(A,comm_nod,'exp',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commhyb(A,%d,''exp'',%d,opts)',comm_nod,m);
							case 2
								tic
								[vip, vipvalue, info, S, ~, ~, ~] = commlr(A,comm_nod,'exp',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commlr(A,%d,''exp'',%d,opts)',comm_nod,m);
								
							case 3
								tic
								[vip, vipvalue, info, ~, ~] = commgauss(A,comm_nod,'exp',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commgauss(A,%d,''exp'',%d,opts)',comm_nod,m);
						end
						%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					end
				case 3      %starting convenience
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					switch way
						case 1
							tic
							[vip, vipvalue, info, ~, ~, S, ~] = stconvhyb(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvnhyb(A,''exp'',%d,opts)',m);
						case 2
							tic
							[vip, vipvalue, info, S, ~, ~, ~] = stconvlr(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvlr(A,''exp'',%d,opts)',m);
						case 3
							tic
							[vip, vipvalue, info, ~, ~] = stconvgauss(A,'exp',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvgauss(A,''exp'',%d,opts)',m);
					end
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
			end
		case 2      %resolvent
			rho = eigs(A,1,'LA');
			opts.alpha = str2double(get(handles.editalpha,'string'));
			if isnan(opts.alpha) || (opts.alpha < 0 ) || (opts.alpha > 1/rho)
				str = sprintf('Please specify a valid value for alpha!');
				uiwait(warndlg(str,'Warning','modal'));
				stralpha = sprintf('(0 < alpha < %f)',1/rho);
				set(handles.editalpha,'Enable', 'on','string',stralpha);
				set(handles.text19,'string','')
				set(handles.text19,'horizontalalignment','left','fontweight','normal');
				return
			end
			switch index
				case 1 % subgraph centrality
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					switch way
						case 1
							tic
							[vip, vipvalue, info, ~, ~, S, ~] = sgcenhyb(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcenhyb(A,''res'',%d,opts)',m);
						case 2
							tic
							[vip, vipvalue, info, S, ~, ~, ~] = sgcenlr(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcenlr(A,''res'',%d,opts)',m);
						case 3
							tic
							[vip, vipvalue, info, ~, ~] = sgcengauss(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = sgcengauss(A,''res'',%d,opts)',m);
					end
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
				case 2      %communicability
					comm_nod = str2double(get(handles.comm_node,'string'));
					if isnan(comm_nod)
						str = sprintf('Please specify a node!');
						uiwait(warndlg(str,'Warning','modal'));
						set(handles.text19,'string','')
						set(handles.text19,'horizontalalignment','left','fontweight','normal');
						return
					elseif ~sum(A(:,comm_nod))
						str = sprintf('Node %d is not connected',comm_nod);
						uiwait(warndlg(str,'Warning','modal'));
						set(handles.text19,'string','')
						set(handles.text19,'horizontalalignment','left','fontweight','normal');
						return
					else
						%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
						switch way
							case 1
								tic
								[vip, vipvalue, info, ~, ~, S, ~] = commhyb(A,comm_nod,'res',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commhyb(A,%d,''res'',%d,opts)',comm_nod,m);
							case 2
								tic
								[vip, vipvalue, info, S, ~, ~, ~] = commlr(A,comm_nod,'res',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commlr(A,%d,''res'',%d,opts)',comm_nod,m);
							case 3
								tic
								[vip, vipvalue, info, ~, ~] = commgauss(A,comm_nod,'res',m,opts);
								tim = toc;
								infostr = sprintf('[vip,vipvalue,info] = commgauss(A,%d,''res'',%d,opts)',comm_nod,m);
						end
						%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					end
				case 3      %starting convenience
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
					switch way
						case 1
							tic
							[vip, vipvalue, info, ~, ~, S, ~] = stconvhyb(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvhyb(A,''res'',%d,opts)',m);
						case 2
							tic
							[vip, vipvalue, info, S, ~, ~, ~] = stconvlr(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvlr(A,''res'',%d,opts)',m);
						case 3
							tic
							[vip, vipvalue, info, ~, ~] = stconvgauss(A,'res',m,opts);
							tim = toc;
							infostr = sprintf('[vip,vipvalue,info] = stconvgauss(A,''res'',%d,opts)',m);
					end
					%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
			end
	end
	
	%keyboard
	
	switch way
		case 1
			s0 = sprintf('Computation done via Hybrid method:\n');
			realN = length(S);
			if length(S{end}) == n
				str_conv = sprintf('Results may be inaccurate, try decreasing tolerance for low-rank');
				uiwait(warndlg(str_conv,'Warning','modal'));
			end
			nvip = length(vip);
			switch info(1)
				case 0
					s1 = sprintf('\n\nStrong convergence test was satisfied.\n');
				case 1
					s1 = sprintf('\n\nWeak convergence test was satisfied.\n');
				case 2
					s1 = sprintf('\n\nNo convergence test was satisfied.\n');
			end
			s2 = sprintf('Number of used eigenpairs : %d \n%d VIP node',realN,nvip);
			if nvip > 1
				s3 = sprintf('s identified.\n');
			else
				s3 = sprintf(' identified.\n');
			end
			s4 = sprintf('\nElapsed time: %.2e. (%s animation)',tim,str_show);
			s = [s0 infostr s1 s2 s3 s4];
		case 2
			s0 = sprintf('Computation done via Low-rank with strong convergence condition method:\n');
			realN = length(S);
			nvip = length(vip);
			switch info(1)
				case 0
					s1 = sprintf('\nStrong convergence test was satisfied.\n');
				case 1
					s1 = sprintf('\nWeak convergence test was satisfied.\n');
				case 2
					s1 = sprintf('\nNo convergence test was satisfied.\n');
			end
			s2 = sprintf('Number of used eigenpairs : %d. \n%d VIP node',realN,nvip);
			if nvip > 1
				s3 = sprintf('s identified.\n');
			else
				s3 = sprintf(' identified.\n');
			end
			s4 = sprintf('\nElapsed time: %.2e. (%s animation)',tim,str_show);
			s = [s0 infostr s1 s2 s3 s4];
		case 3
			s = sprintf('Computation done via Gauss Quadrature method:\n');
			s4 = sprintf('\nElapsed time: %.2e. (%s animation)',tim,str_show);
			s = [s infostr s4];
	end
	
	set(handles.text19,'string',s)
	set(handles.text19,'horizontalalignment','left','fontweight','normal');
	set(handles.table,'visible','on');
	colnames = {'Node','Value'};
	set(handles.table,'Data',[vip vipvalue], 'ColumnName', colnames)
	
	handles.old_vip = handles.res.vip;
	handles.old_value = handles.res.vip_value;
	
	
	handles.res.vip = vip;
	handles.res.vip_value = vipvalue;
	handles.res.info = info;
	
	
	guidata(handles.figure1,handles);
	
end

end

